pub enum PublicCommand {
Summary {
index_root: PathBuf,
host: String,
owner: String,
repo: String,
base_path: String,
stale_after_hours: Option<i64>,
},
Profile {
index_root: PathBuf,
host: String,
owner: String,
repo: String,
base_path: String,
stale_after_hours: Option<i64>,
},
BatchProfiles {
index_root: PathBuf,
repos: Vec<String>,
base_path: String,
stale_after_hours: Option<i64>,
},
BatchQuery {
index_root: PathBuf,
repos: Vec<String>,
paths: Vec<String>,
base_path: String,
stale_after_hours: Option<i64>,
},
Compare {
index_root: PathBuf,
repos: Vec<String>,
base_path: String,
stale_after_hours: Option<i64>,
},
Relations {
index_root: PathBuf,
host: String,
owner: String,
repo: String,
base_path: String,
stale_after_hours: Option<i64>,
},
Search {Show 14 fields
index_root: PathBuf,
q: Option<String>,
languages: Vec<String>,
topics: Vec<String>,
statuses: Vec<String>,
confidences: Vec<String>,
require_build: bool,
require_test: bool,
require_docs: bool,
require_security_contact: bool,
require_license: bool,
limit: Option<usize>,
base_path: String,
stale_after_hours: Option<i64>,
},
Trust {
index_root: PathBuf,
host: String,
owner: String,
repo: String,
base_path: String,
stale_after_hours: Option<i64>,
},
Query {
index_root: PathBuf,
host: String,
owner: String,
repo: String,
path: String,
base_path: String,
stale_after_hours: Option<i64>,
},
Export {
index_root: PathBuf,
out_dir: PathBuf,
base_path: String,
stale_after_hours: Option<i64>,
generated_at: Option<String>,
stale_after: Option<String>,
pagedigest_previous: Option<PathBuf>,
},
}Variants
Summary
Render one public repository summary response as JSON.
Fields
Profile
Render one compact public research profile response as JSON.
Fields
BatchProfiles
Render compact public research profiles for multiple repositories.
Fields
BatchQuery
Render public query responses for multiple repositories and dot paths.
Fields
Compare
Compare compact public research profiles for multiple repositories.
Fields
Relations
Traverse public repository references declared in the selected profile.
Fields
Search
Search compact public research profiles by text and structured filters.
Fields
Trust
Render one public trust response as JSON.
Fields
Query
Render one public query response as JSON.
Fields
Export
Export the static-first public JSON tree for repository summary, profile, and trust.
Fields